@@ -391,6 +391,50 @@ class ObsoleteUriCheck(Check):
                     yield ObsoleteUri(lineno, uri, regexp.sub(repl, uri), pkg=pkg)
 
 
+class BetterCompressionUri(results.LineResult, results.Style):
+    """URI provider has better compression suggestion.
+
+    The URI used to fetch distfile doesn't use the best compression
+    available from the provider. Using better compression can save
+    bandwidth for the users and mirrors.
+    """
+
+    def __init__(self, replacement, **kwargs):
+        super().__init__(**kwargs)
+        self.replacement = replacement
+
+    @property
+    def desc(self):
+        return (f"line {self.lineno}: better compression URI using extension "
+                f"{self.replacement!r} for {self.line!r}")
+
+
+class BetterCompressionCheck(Check):
+    """Scan ebuild for URIs with better compression."""
+
+    _source = sources.EbuildFileRepoSource
+    known_results = frozenset([BetterCompressionUri])
+
+    REGEXPS = (
+        (r'.*\b(?P<uri>https?://[^/]*?gitlab[^/]*?/.*/-/archive/.*?/\S*\.(?:tar\.gz|tar(?!.bz2)|zip))',
+         '.tar.bz2'),
+    )
+
+    def __init__(self, *args):
+        super().__init__(*args)
+        self.regexes = tuple((re.compile(regexp), repl) for regexp, repl in self.REGEXPS)
+
+    def feed(self, pkg):
+        for lineno, line in enumerate(pkg.lines, 1):
+            if not line.strip() or line.startswith('#'):
+                continue
+            # searching for multiple matches on a single line is too slow
+            for regexp, replacement in self.regexes:
+                if mo := regexp.match(line):
+                    uri = mo.group('uri')
+                    yield BetterCompressionUri(replacement, lineno=lineno, line=uri, pkg=pkg)
+
+
 class HomepageInSrcUri(results.VersionResult, results.Style):
     """${HOMEPAGE} is referenced in SRC_URI.
 
@@ -975,6 +1019,11 @@ class _UnquotedVariablesCheck(Check):
         # Variable is part of a shell assignment, and does not need to be
         # quoted. for example S=${WORKDIR}/${PN} is ok.
         'variable_assignment',
+        # Variable is being used in a unset command.
+        'unset_command',
+        # Variable is part of declaring variables, and does not need to be
+        # quoted. for example local TMPDIR is ok.
+        'declaration_command',
         # Variable sits inside a [[ ]] test command and it's OK not to be quoted
         'test_command',
         # Variable is being used in a heredoc body, no need to specify quotes.
@@ -1035,3 +1084,137 @@ class EclassUnquotedVariablesCheck(_UnquotedVariablesCheck):
     def feed(self, eclass):
         for var_name, lines in self._feed(eclass):
             yield EclassUnquotedVariable(var_name, lines=lines, eclass=eclass.name)
+
+
+class ExcessiveLineLength(results.LinesResult, results.Style):
+    """Line is longer than 120 characters."""
+
+    line_length = 120
+    word_length = 110
+
+    @property
+    def desc(self):
+        return f'excessive line length (over {self.line_length} characters) {self.lines_str}'
+
+
+class LineLengthCheck(Check):
+    """Scan ebuild for lines with excessive length."""
+
+    _source = sources.EbuildFileRepoSource
+    known_results = frozenset([ExcessiveLineLength])
+
+    def __init__(self, options, **kwargs):
+        super().__init__(options, **kwargs)
+        self.exception = re.compile(r'\s*(?:DESCRIPTION|KEYWORDS|IUSE)=')
+        str_length = f'[^\'\"]{{{ExcessiveLineLength.word_length},}}'
+        self.long_string = re.compile(rf'"{str_length}"|\'{str_length}\'')
+
+    def feed(self, pkg):
+        lines = []
+        for lineno, line in enumerate(pkg.lines, 1):
+            if len(line) <= ExcessiveLineLength.line_length:
+                continue
+            if self.exception.match(line):
+                continue # exception variables which are fine to be long
+            if max(map(len, line.split())) > ExcessiveLineLength.word_length:
+                continue # if one part of the line is very long word
+            if self.long_string.search(line):
+                continue # skip lines with long quoted string
+            lines.append(lineno)
+        if lines:
+            yield ExcessiveLineLength(lines=lines, pkg=pkg)
+
+
+class InstallCompressedManpage(results.LineResult, results.Warning):
+    """Compressed manpages are not supported by ``doman`` or ``newman``."""
+
+    def __init__(self, func, **kwargs):
+        super().__init__(**kwargs)
+        self.func = func
+
+    @property
+    def desc(self):
+        return f'line {self.lineno}: compressed manpage {self.line!r} passed to {self.func}'
+
+
+class InstallCompressedInfo(results.LineResult, results.Warning):
+    """Compressed manpages are not supported by ``doinfo``."""
+
+    def __init__(self, func, **kwargs):
+        super().__init__(**kwargs)
+        self.func = func
+
+    @property
+    def desc(self):
+        return f'line {self.lineno}: compressed info {self.line!r} passed to {self.func}'
+
+
+class DoCompressedFilesCheck(Check):
+    """Scan ebuild for compressed files passed to ``do*`` or ``new**``."""
+
+    _source = sources.EbuildParseRepoSource
+    known_results = frozenset([InstallCompressedManpage, InstallCompressedInfo])
+
+    compresion_extentions = ('.Z', '.gz', '.bz2', '.lzma', '.lz', '.lzo', '.lz4', '.xz', '.zst')
+    functions = ImmutableDict({
+        'doman': InstallCompressedManpage,
+        'newman': InstallCompressedManpage,
+        'doinfo': InstallCompressedInfo,
+    })
+
+    def feed(self, pkg):
+        for node, _ in bash.cmd_query.captures(pkg.tree.root_node):
+            call_name = pkg.node_str(node.child_by_field_name('name'))
+            if call_name not in self.functions:
+                continue
+            for arg in node.children[1:]:
+                arg_name = pkg.node_str(arg).strip('\'\"')
+                lineno, _ = arg.start_point
+                if arg_name.endswith(self.compresion_extentions):
+                    yield self.functions[call_name](call_name, lineno=lineno+1, line=arg_name, pkg=pkg)
+
+
+class NonPosixHeadTailUsage(results.LineResult, results.Warning):
+    """Using of non-POSIX compliant ``head`` or ``tail``.
+
+    The numeric argument to ``head`` or ``tail`` without ``-n`` (for example
+    ``head -10``) is deprecated and not POSIX compliant. To fix, prepand ``-n``
+    before the number [#]_.
+
+    .. [#] https://devmanual.gentoo.org/tools-reference/head-and-tail/index.html
+    """
+    def __init__(self, command, **kwargs):
+        super().__init__(**kwargs)
+        self.command = command
+
+    @property
+    def desc(self):
+        return f'line {self.lineno}: non-posix usage of {self.command!r}: {self.line!r}'
+
+
+class NonPosixCheck(Check):
+    """Scan ebuild for non-posix usage, code which might be not portable."""
+
+    _source = sources.EbuildParseRepoSource
+    known_results = frozenset([NonPosixHeadTailUsage])
+
+    def __init__(self, options, **kwargs):
+        super().__init__(options, **kwargs)
+        self.re_head_tail = re.compile(r'[+-]\d+')
+
+    def check_head_tail(self, pkg, call_node, call_name):
+        prev_arg = ''
+        for arg in map(pkg.node_str, call_node.children[1:]):
+            if (self.re_head_tail.match(arg) and
+                not (prev_arg.startswith('-') and prev_arg.endswith(('n', 'c')))):
+                lineno, _ = call_node.start_point
+                yield NonPosixHeadTailUsage(f'{call_name} {arg}',
+                    lineno=lineno+1, line=pkg.node_str(call_node), pkg=pkg)
+                break
+            prev_arg = arg
+
+    def feed(self, pkg):
+        for call_node, _ in bash.cmd_query.captures(pkg.tree.root_node):
+            call_name = pkg.node_str(call_node.child_by_field_name('name'))
+            if call_name in ('head', 'tail'):
+                yield from self.check_head_tail(pkg, call_node, call_name)
