@@ -315,6 +315,48 @@ class TestObsoleteUri(misc.ReportTestCase):
         assert uri in str(r)
 
 
+class TestBetterCompression(misc.ReportTestCase):
+
+    check_kls = codingstyle.BetterCompressionCheck
+
+    def test_github_archive_uri(self):
+        uri = 'https://github.com/foo/bar/archive/${PV}.tar.gz'
+        fake_src = [
+            f'SRC_URI="{uri} -> ${{P}}.tar.gz"\n'
+        ]
+        fake_pkg = misc.FakePkg("dev-util/diffball-0.5", lines=fake_src)
+        self.assertNoReport(self.check_kls(None), fake_pkg)
+
+    def test_comment_uri(self):
+        uri = 'https://gitlab.com/GNOME/${PN}/-/archive/${PV}/${P}.tar'
+        fake_src = [
+            f'#SRC_URI="{uri} -> ${{P}}.tar.gz"\n',
+            " ",
+            "    ",
+            f'SRC_URI="{uri} -> ${{P}}.tar.gz"\n',
+        ]
+        fake_pkg = misc.FakePkg("dev-util/diffball-0.5", lines=fake_src)
+        r = self.assertReport(self.check_kls(None), fake_pkg)
+        assert r.lineno == 4
+
+    @pytest.mark.parametrize('uri', (
+        'https://gitlab.com/GNOME/${PN}/-/archive/${PV}/${P}.tar',
+        'https://gitlab.gnome.org/GNOME/${PN}/-/archive/${PV}/${P}.tar.gz',
+        'https://gitlab.gnome.org/GNOME/${PN}/-/archive/${PV}/${P}.zip',
+        'https://gitlab.freedesktop.org/glvnd/${PN}/-/archive/v${PV}/${PN}-v${PV}.tar.gz',
+    ))
+    def test_gitlab_archive_uri(self, uri):
+        fake_src = [
+            f'SRC_URI="{uri} -> ${{P}}.tar.gz"\n'
+        ]
+        fake_pkg = misc.FakePkg("dev-util/diffball-0.5", lines=fake_src)
+        r = self.assertReport(self.check_kls(None), fake_pkg)
+        assert r.lineno == 1
+        assert r.line == uri
+        assert r.replacement == '.tar.bz2'
+        assert uri in str(r)
+
+
 class TestStaticSrcUri(misc.ReportTestCase):
 
     check_kls = codingstyle.MetadataVarCheck
@@ -391,3 +433,62 @@ class TestStaticSrcUri(misc.ReportTestCase):
         r = self.assertReport(self.check, self._prepare_pkg('Diffball-0.1.2.3', pkgver='Diffball-0.1.2.3'))
         assert r.static_str == 'Diffball-0.1.2.3'
         assert r.replacement == '${P}'
+
+
+class TestExcessiveLineLength(misc.ReportTestCase):
+
+    check_kls = codingstyle.LineLengthCheck
+    check = check_kls(None)
+    word_length = codingstyle.ExcessiveLineLength.word_length
+
+
+    @staticmethod
+    def _prepare_pkg(*lines: str):
+        fake_pkg = misc.FakePkg("dev-util/diffball-0", ebuild=''.join(lines), lines=lines)
+        data = ''.join(lines).encode()
+        return _ParsedPkg(data, pkg=fake_pkg)
+
+    def test_normal_length(self):
+        self.assertNoReport(self.check, self._prepare_pkg('echo "short line"'))
+
+    def test_long_line(self):
+        r = self.assertReport(self.check, self._prepare_pkg(f'echo {"a " * codingstyle.ExcessiveLineLength.line_length}'))
+        assert r.lines == (1, )
+
+    def test_multiple_lines(self):
+        r = self.assertReport(self.check, self._prepare_pkg(
+            f'echo {"a " * codingstyle.ExcessiveLineLength.line_length}',
+            'echo "short line"',
+            f'echo {"Hello " * codingstyle.ExcessiveLineLength.line_length}',
+        ))
+        assert r.lines == (1, 3)
+
+    @pytest.mark.parametrize('variable', ('DESCRIPTION', 'KEYWORDS', 'IUSE'))
+    def test_special_variables(self, variable):
+        self.assertNoReport(self.check, self._prepare_pkg(
+            f'{variable}="{"a " * codingstyle.ExcessiveLineLength.line_length}"',
+            f'    {variable}="{"a " * codingstyle.ExcessiveLineLength.line_length}"',
+            f'\t\t{variable}="{"a " * codingstyle.ExcessiveLineLength.line_length}"',
+        ))
+
+    def test_long_words(self):
+        long_word = 'a' * self.word_length + 'b'
+        medium_word = 'a' * (self.word_length // 2)
+        r = self.assertReport(self.check, self._prepare_pkg(
+            f'echo {"a" * codingstyle.ExcessiveLineLength.line_length}',
+            f'echo {medium_word} {long_word}',
+            f'echo {medium_word} {long_word[:-5]}',
+        ))
+        assert r.lines == (3, )
+
+    def test_long_quotes(self):
+        # The exception is for any quoted string with length >= word_length.
+        # Each quoted string is computed by itself.
+        long_word = 'a ' * (self.word_length // 2) + 'b' # long quoted string, skipped
+        medium_word = 'a ' * (self.word_length // 4) # not long enough string, not skipped
+        r = self.assertReport(self.check, self._prepare_pkg(
+            f'echo "{"a" * codingstyle.ExcessiveLineLength.line_length}"',
+            f'echo "{medium_word}" "{long_word}"',
+            'echo' + f' "{medium_word}"' * 3,
+        ))
+        assert r.lines == (3, )
